@@ -75,7 +75,9 @@ class TextOutput(base.BaseOutput):
         if 'imphash' in p:
             output.append(self._white('Imphash: {}'.format(p['imphash'])))
         output.append(self._white('First seen: {}'.format(artifact.first_seen)))
-        output.append(self._white('Last seen: {}'.format(artifact.last_seen)))
+        output.append(self._white('Last scanned: {}'.format(artifact.last_scanned)))
+        # Deprecated
+        output.append(self._white('Last seen: {}'.format(artifact.last_scanned)))
         return self._output(output, write)
 
     def artifact_instance(self, instance, write=True, timeout=False):
@@ -215,8 +217,11 @@ class TextOutput(base.BaseOutput):
 
         if instance.first_seen:
             output.append(self._white('First seen: {}'.format(instance.first_seen)))
-        if instance.last_seen:
-            output.append(self._white('Last seen: {}'.format(instance.last_seen)))
+        if instance.last_scanned:
+            output.append(self._white('Last scanned: {}'.format(instance.last_scanned)))
+            # Deprecated
+            output.append(self._white('Last seen: {}'.format(instance.last_scanned)))
+
         if instance.mimetype:
             output.append(self._white('Mimetype: {}'.format(instance.mimetype)))
         if instance.extended_mimetype:
